==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/theme.dart <==
import 'package:flutter/material.dart';
import 'color.dart';

// ===== ThemeData for Yellow theme =====
ThemeData YellowThemeData() {
  final baseTheme = ThemeData.light();
  return baseTheme.copyWith(
    tabBarTheme: baseTheme.tabBarTheme.copyWith(
      indicator: UnderlineTabIndicator(
        borderSide: BorderSide(
          color: AppColorsYellow.kWhite,
          width: 2.0,
        ),
      ),
      labelColor: AppColorsYellow.kWhite,
      unselectedLabelColor: AppColorsYellow.tlColor,
    ),
    brightness: Brightness.light,
    accentColor: AppColorsYellow.gaColor,
    primaryColor: AppColorsYellow.tColor,
    primaryColorDark: AppColorsYellow.tdColor,
    floatingActionButtonTheme: baseTheme.floatingActionButtonTheme.copyWith(
      backgroundColor: AppColorsYellow.gaColor,
      foregroundColor: AppColorsYellow.kWhite,
    ),
    scaffoldBackgroundColor: AppColorsYellow.bgColor,
    backgroundColor: AppColorsYellow.bgColor,
    iconTheme: baseTheme.iconTheme.copyWith(
      color: AppColorsYellow.kWhite,
    ),
    primaryIconTheme: baseTheme.primaryIconTheme.copyWith(
      color: AppColorsYellow.kWhite,
    ),
    accentIconTheme: baseTheme.accentIconTheme.copyWith(
      color: AppColorsYellow.kWhite,
    ),
    textTheme: baseTheme.textTheme.apply(
      fontFamily: 'Roboto',
    ),
  );
}

// ===== ThemeData for MediumGrey theme =====
ThemeData MediumGreyThemeData() {
  final baseTheme = ThemeData.dark();
  return baseTheme.copyWith(
      tabBarTheme: baseTheme.tabBarTheme.copyWith(
        indicator: UnderlineTabIndicator(
          borderSide: BorderSide(
            color: AppColorsMediumGrey.groupWidgetColor,
            width: 2.0,
          ),
        ),
        labelColor: AppColorsMediumGrey.yellow,
        unselectedLabelColor: AppColorsMediumGrey.yellow,
      ),
      brightness: Brightness.dark,
      accentColor: AppColorsMediumGrey.groupWidgetColor,
      primaryColor: AppColorsMediumGrey.bGColor,
      primaryColorDark: AppColorsMediumGrey.bgColor,
      primaryColorLight: AppColorsMediumGrey.groupWidgetColor,
      canvasColor: AppColorsMediumGrey.groupWidgetColor,
      bottomAppBarColor: AppColorsMediumGrey.groupWidgetColor,
      cardColor: AppColorsMediumGrey.groupWidgetColor,
      dividerColor: AppColorsMediumGrey.groupWidgetColor,
      focusColor: AppColorsMediumGrey.groupWidgetColor,
      hoverColor: AppColorsMediumGrey.groupWidgetColor,
      highlightColor: AppColorsMediumGrey.groupWidgetColor,
      splashColor: AppColorsMediumGrey.groupWidgetColor,
      selectedRowColor: AppColorsMediumGrey.groupWidgetColor,
      unselectedWidgetColor: AppColorsMediumGrey.groupWidgetColor,
      disabledColor: AppColorsMediumGrey.groupWidgetColor,
      buttonColor: AppColorsMediumGrey.groupWidgetColor,
      secondaryHeaderColor: AppColorsMediumGrey.groupWidgetColor,
      textSelectionColor: AppColorsMediumGrey.groupWidgetColor,
      cursorColor: AppColorsMediumGrey.groupWidgetColor,
      textSelectionHandleColor: AppColorsMediumGrey.groupWidgetColor,
      dialogBackgroundColor: AppColorsMediumGrey.groupWidgetColor,
      indicatorColor: AppColorsMediumGrey.groupWidgetColor,
      hintColor: AppColorsMediumGrey.groupWidgetColor,
      errorColor: AppColorsMediumGrey.groupWidgetColor,
      toggleableActiveColor: AppColorsMediumGrey.groupWidgetColor,
      /*sliderTheme: AppColorsMediumGrey.groupWidgetColor,
      tabBarTheme: AppColorsMediumGrey.groupWidgetColor,
      tooltipTheme: AppColorsMediumGrey.groupWidgetColor,
      cardTheme: AppColorsMediumGrey.groupWidgetColor,
      chipTheme: AppColorsMediumGrey.groupWidgetColor,
      platform: AppColorsMediumGrey.groupWidgetColor,
      materialTapTargetSize: AppColorsMediumGrey.groupWidgetColor,
      applyElevationOverlayColor: AppColorsMediumGrey.groupWidgetColor,
      pageTransitionsTheme: AppColorsMediumGrey.groupWidgetColor,
      appBarTheme: AppColorsMediumGrey.groupWidgetColor,
      bottomAppBarTheme: AppColorsMediumGrey.groupWidgetColor,
      colorScheme: AppColorsMediumGrey.groupWidgetColor,
      dialogTheme: AppColorsMediumGrey.groupWidgetColor,
      typography: AppColorsMediumGrey.groupWidgetColor,
      cupertinoOverrideTheme: AppColorsMediumGrey.groupWidgetColor,
      snackBarTheme: AppColorsMediumGrey.groupWidgetColor,
      bottomSheetTheme: AppColorsMediumGrey.groupWidgetColor,
      popupMenuTheme: AppColorsMediumGrey.groupWidgetColor,
      bannerTheme: AppColorsMediumGrey.groupWidgetColor,
      dividerTheme: AppColorsMediumGrey.groupWidgetColor,
      buttonBarTheme: AppColorsMediumGrey.groupWidgetColor,*/
      floatingActionButtonTheme: baseTheme.floatingActionButtonTheme.copyWith(
        backgroundColor: AppColorsMediumGrey.groupWidgetColor,
        foregroundColor: AppColorsMediumGrey.white,
      ),
      scaffoldBackgroundColor: AppColorsMediumGrey.bgColor,
      backgroundColor: AppColorsMediumGrey.bGColor,
      iconTheme: baseTheme.iconTheme.copyWith(
        color: AppColorsMediumGrey.white,
      ),
      primaryIconTheme: baseTheme.primaryIconTheme.copyWith(
        color: AppColorsMediumGrey.white,
      ),
      accentIconTheme: baseTheme.accentIconTheme.copyWith(
        color: AppColorsMediumGrey.darkGrey,
      ),
      textTheme: baseTheme.textTheme.apply(
        fontFamily: 'Helvetica',
      )
  );
}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/theme.dart <==
import 'package:flutter/material.dart';
import 'color.dart';

// ===== ThemeData for Yellow theme =====
ThemeData yellowThemeData() {
  final baseTheme = ThemeData.light();
  return baseTheme.copyWith(
    tabBarTheme: baseTheme.tabBarTheme.copyWith(
      indicator: UnderlineTabIndicator(
        borderSide: BorderSide(
          color: AppColorsYellow.kWhite,
          width: 2.0,
        ),
      ),
      labelColor: AppColorsYellow.kWhite,
      unselectedLabelColor: AppColorsYellow.tlColor,
    ),
    brightness: Brightness.light,
    accentColor: AppColorsYellow.gaColor,
    primaryColor: AppColorsYellow.tColor,
    primaryColorDark: AppColorsYellow.tdColor,
    floatingActionButtonTheme: baseTheme.floatingActionButtonTheme.copyWith(
      backgroundColor: AppColorsYellow.gaColor,
      foregroundColor: AppColorsYellow.kWhite,
    ),
    scaffoldBackgroundColor: AppColorsYellow.bgColor,
    backgroundColor: AppColorsYellow.bgColor,
    iconTheme: baseTheme.iconTheme.copyWith(
      color: AppColorsYellow.kWhite,
    ),
    primaryIconTheme: baseTheme.primaryIconTheme.copyWith(
      color: AppColorsYellow.kWhite,
    ),
    accentIconTheme: baseTheme.accentIconTheme.copyWith(
      color: AppColorsYellow.kWhite,
    ),
    textTheme: baseTheme.textTheme.apply(
      fontFamily: 'Roboto',
    ),
  );
}

// ===== ThemeData for MediumGrey theme =====
ThemeData mediumGreyThemeData() {
  final baseTheme = ThemeData.dark();
  return baseTheme.copyWith(
      tabBarTheme: baseTheme.tabBarTheme.copyWith(
        indicator: UnderlineTabIndicator(
          borderSide: BorderSide(
            color: AppColorsMediumGrey.groupWidgetColor,
            width: 2.0,
          ),
        ),
        labelColor: AppColorsMediumGrey.yellow,
        unselectedLabelColor: AppColorsMediumGrey.yellow,
      ),
      brightness: Brightness.dark,
      accentColor: AppColorsMediumGrey.groupWidgetColor,
      primaryColor: AppColorsMediumGrey.bGColor,
      primaryColorDark: AppColorsMediumGrey.bgColor,
      primaryColorLight: AppColorsMediumGrey.groupWidgetColor,
      canvasColor: AppColorsMediumGrey.groupWidgetColor,
      bottomAppBarColor: AppColorsMediumGrey.groupWidgetColor,
      cardColor: AppColorsMediumGrey.groupWidgetColor,
      dividerColor: AppColorsMediumGrey.groupWidgetColor,
      focusColor: AppColorsMediumGrey.groupWidgetColor,
      hoverColor: AppColorsMediumGrey.groupWidgetColor,
      highlightColor: AppColorsMediumGrey.groupWidgetColor,
      splashColor: AppColorsMediumGrey.groupWidgetColor,
      selectedRowColor: AppColorsMediumGrey.groupWidgetColor,
      unselectedWidgetColor: AppColorsMediumGrey.groupWidgetColor,
      disabledColor: AppColorsMediumGrey.groupWidgetColor,
      buttonColor: AppColorsMediumGrey.groupWidgetColor,
      secondaryHeaderColor: AppColorsMediumGrey.groupWidgetColor,
      textSelectionColor: AppColorsMediumGrey.groupWidgetColor,
      cursorColor: AppColorsMediumGrey.groupWidgetColor,
      textSelectionHandleColor: AppColorsMediumGrey.groupWidgetColor,
      dialogBackgroundColor: AppColorsMediumGrey.groupWidgetColor,
      indicatorColor: AppColorsMediumGrey.groupWidgetColor,
      hintColor: AppColorsMediumGrey.groupWidgetColor,
      errorColor: AppColorsMediumGrey.groupWidgetColor,
      toggleableActiveColor: AppColorsMediumGrey.groupWidgetColor,
      /*sliderTheme: AppColorsMediumGrey.groupWidgetColor,
      tabBarTheme: AppColorsMediumGrey.groupWidgetColor,
      tooltipTheme: AppColorsMediumGrey.groupWidgetColor,
      cardTheme: AppColorsMediumGrey.groupWidgetColor,
      chipTheme: AppColorsMediumGrey.groupWidgetColor,
      platform: AppColorsMediumGrey.groupWidgetColor,
      materialTapTargetSize: AppColorsMediumGrey.groupWidgetColor,
      applyElevationOverlayColor: AppColorsMediumGrey.groupWidgetColor,
      pageTransitionsTheme: AppColorsMediumGrey.groupWidgetColor,
      appBarTheme: AppColorsMediumGrey.groupWidgetColor,
      bottomAppBarTheme: AppColorsMediumGrey.groupWidgetColor,
      colorScheme: AppColorsMediumGrey.groupWidgetColor,
      dialogTheme: AppColorsMediumGrey.groupWidgetColor,
      typography: AppColorsMediumGrey.groupWidgetColor,
      cupertinoOverrideTheme: AppColorsMediumGrey.groupWidgetColor,
      snackBarTheme: AppColorsMediumGrey.groupWidgetColor,
      bottomSheetTheme: AppColorsMediumGrey.groupWidgetColor,
      popupMenuTheme: AppColorsMediumGrey.groupWidgetColor,
      bannerTheme: AppColorsMediumGrey.groupWidgetColor,
      dividerTheme: AppColorsMediumGrey.groupWidgetColor,
      buttonBarTheme: AppColorsMediumGrey.groupWidgetColor,*/
      floatingActionButtonTheme: baseTheme.floatingActionButtonTheme.copyWith(
        backgroundColor: AppColorsMediumGrey.groupWidgetColor,
        foregroundColor: AppColorsMediumGrey.white,
      ),
      scaffoldBackgroundColor: AppColorsMediumGrey.bgColor,
      backgroundColor: AppColorsMediumGrey.bGColor,
      iconTheme: baseTheme.iconTheme.copyWith(
        color: AppColorsMediumGrey.white,
      ),
      primaryIconTheme: baseTheme.primaryIconTheme.copyWith(
        color: AppColorsMediumGrey.white,
      ),
      accentIconTheme: baseTheme.accentIconTheme.copyWith(
        color: AppColorsMediumGrey.darkGrey,
      ),
      textTheme: baseTheme.textTheme.apply(
        fontFamily: 'Helvetica',
      )
  );
}
